# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'fldviewdlg.ui'
#
# Created: Fri Oct 26 14:04:46 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_fldviewdlg(object):
    def setupUi(self, fldviewdlg):
        fldviewdlg.setObjectName(_fromUtf8("fldviewdlg"))
        fldviewdlg.resize(460, 481)
        self.buttonBox = QtGui.QDialogButtonBox(fldviewdlg)
        self.buttonBox.setGeometry(QtCore.QRect(360, 10, 81, 71))
        self.buttonBox.setOrientation(QtCore.Qt.Vertical)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(fldviewdlg)
        self.label.setGeometry(QtCore.QRect(30, 30, 91, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.jorv = QtGui.QLabel(fldviewdlg)
        self.jorv.setGeometry(QtCore.QRect(130, 30, 101, 17))
        self.jorv.setObjectName(_fromUtf8("jorv"))
        self.possattr = QtGui.QComboBox(fldviewdlg)
        self.possattr.setGeometry(QtCore.QRect(30, 80, 381, 27))
        self.possattr.setObjectName(_fromUtf8("possattr"))
        self.currattr = QtGui.QListWidget(fldviewdlg)
        self.currattr.setGeometry(QtCore.QRect(30, 130, 381, 271))
        self.currattr.setDragDropMode(QtGui.QAbstractItemView.InternalMove)
        self.currattr.setObjectName(_fromUtf8("currattr"))
        self.addattr = QtGui.QPushButton(fldviewdlg)
        self.addattr.setGeometry(QtCore.QRect(30, 430, 93, 27))
        self.addattr.setObjectName(_fromUtf8("addattr"))
        self.delattr = QtGui.QPushButton(fldviewdlg)
        self.delattr.setGeometry(QtCore.QRect(310, 430, 93, 27))
        self.delattr.setObjectName(_fromUtf8("delattr"))

        self.retranslateUi(fldviewdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), fldviewdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), fldviewdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(fldviewdlg)
        fldviewdlg.setTabOrder(self.possattr, self.currattr)
        fldviewdlg.setTabOrder(self.currattr, self.addattr)
        fldviewdlg.setTabOrder(self.addattr, self.delattr)
        fldviewdlg.setTabOrder(self.delattr, self.buttonBox)

    def retranslateUi(self, fldviewdlg):
        fldviewdlg.setWindowTitle(QtGui.QApplication.translate("fldviewdlg", "Select view attributes", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("fldviewdlg", "Attributes of", None, QtGui.QApplication.UnicodeUTF8))
        self.jorv.setText(QtGui.QApplication.translate("fldviewdlg", "jorp", None, QtGui.QApplication.UnicodeUTF8))
        self.possattr.setToolTip(QtGui.QApplication.translate("fldviewdlg", "Possible attribtutes for display", None, QtGui.QApplication.UnicodeUTF8))
        self.currattr.setToolTip(QtGui.QApplication.translate("fldviewdlg", "List of attributes of job or variable to be displayed in column order", None, QtGui.QApplication.UnicodeUTF8))
        self.addattr.setToolTip(QtGui.QApplication.translate("fldviewdlg", "Add attribute to list", None, QtGui.QApplication.UnicodeUTF8))
        self.addattr.setText(QtGui.QApplication.translate("fldviewdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.delattr.setToolTip(QtGui.QApplication.translate("fldviewdlg", "Delete selected attribute from list", None, QtGui.QApplication.UnicodeUTF8))
        self.delattr.setText(QtGui.QApplication.translate("fldviewdlg", "Delete", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'submhdlg.ui'
#
# Created: Thu Jan 31 19:12:45 2013
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_submhdlg(object):
    def setupUi(self, submhdlg):
        submhdlg.setObjectName(_fromUtf8("submhdlg"))
        submhdlg.resize(400, 250)
        self.buttonBox = QtGui.QDialogButtonBox(submhdlg)
        self.buttonBox.setGeometry(QtCore.QRect(160, 180, 201, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(submhdlg)
        self.label.setGeometry(QtCore.QRect(60, 40, 231, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.hostname = QtGui.QComboBox(submhdlg)
        self.hostname.setGeometry(QtCore.QRect(60, 110, 231, 27))
        self.hostname.setObjectName(_fromUtf8("hostname"))

        self.retranslateUi(submhdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), submhdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), submhdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(submhdlg)
        submhdlg.setTabOrder(self.hostname, self.buttonBox)

    def retranslateUi(self, submhdlg):
        submhdlg.setWindowTitle(QtGui.QApplication.translate("submhdlg", "Host for submission of job", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("submhdlg", "Select host for submission of job", None, QtGui.QApplication.UnicodeUTF8))
        self.hostname.setToolTip(QtGui.QApplication.translate("submhdlg", "This is the recipient server for the job", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'btqw_main.ui'
#
# Created: Fri Feb  1 19:24:01 2013
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.resize(800, 600)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/Btqw Icon")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 800, 25))
        self.menubar.setObjectName(_fromUtf8("menubar"))
        self.menu_File = QtGui.QMenu(self.menubar)
        self.menu_File.setObjectName(_fromUtf8("menu_File"))
        self.menu_Window = QtGui.QMenu(self.menubar)
        self.menu_Window.setObjectName(_fromUtf8("menu_Window"))
        self.menu_Action = QtGui.QMenu(self.menubar)
        self.menu_Action.setObjectName(_fromUtf8("menu_Action"))
        self.menu_Jobs = QtGui.QMenu(self.menubar)
        self.menu_Jobs.setObjectName(_fromUtf8("menu_Jobs"))
        self.menu_Conds = QtGui.QMenu(self.menubar)
        self.menu_Conds.setObjectName(_fromUtf8("menu_Conds"))
        self.menu_Search = QtGui.QMenu(self.menubar)
        self.menu_Search.setObjectName(_fromUtf8("menu_Search"))
        self.menu_Help = QtGui.QMenu(self.menubar)
        self.menu_Help.setObjectName(_fromUtf8("menu_Help"))
        self.menu_Variables = QtGui.QMenu(self.menubar)
        self.menu_Variables.setObjectName(_fromUtf8("menu_Variables"))
        self.menuCreate = QtGui.QMenu(self.menubar)
        self.menuCreate.setObjectName(_fromUtf8("menuCreate"))
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        MainWindow.setStatusBar(self.statusbar)
        self.toolBar = QtGui.QToolBar(MainWindow)
        self.toolBar.setObjectName(_fromUtf8("toolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.action_Program_options = QtGui.QAction(MainWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/Program optons")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Program_options.setIcon(icon1)
        self.action_Program_options.setShortcutContext(QtCore.Qt.ApplicationShortcut)
        self.action_Program_options.setObjectName(_fromUtf8("action_Program_options"))
        self.action_Display_options = QtGui.QAction(MainWindow)
        self.action_Display_options.setObjectName(_fromUtf8("action_Display_options"))
        self.action_Save_options = QtGui.QAction(MainWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/save job file")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Save_options.setIcon(icon2)
        self.action_Save_options.setShortcutContext(QtCore.Qt.ApplicationShortcut)
        self.action_Save_options.setObjectName(_fromUtf8("action_Save_options"))
        self.action_Network_stats = QtGui.QAction(MainWindow)
        self.action_Network_stats.setObjectName(_fromUtf8("action_Network_stats"))
        self.action_User_Permissions = QtGui.QAction(MainWindow)
        self.action_User_Permissions.setObjectName(_fromUtf8("action_User_Permissions"))
        self.action_Quit = QtGui.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/Quit program")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Quit.setIcon(icon3)
        self.action_Quit.setShortcutContext(QtCore.Qt.ApplicationShortcut)
        self.action_Quit.setObjectName(_fromUtf8("action_Quit"))
        self.action_Window_options = QtGui.QAction(MainWindow)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/Window options")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Window_options.setIcon(icon4)
        self.action_Window_options.setObjectName(_fromUtf8("action_Window_options"))
        self.action_New_job_window = QtGui.QAction(MainWindow)
        self.action_New_job_window.setObjectName(_fromUtf8("action_New_job_window"))
        self.action_New_variable_window = QtGui.QAction(MainWindow)
        self.action_New_variable_window.setObjectName(_fromUtf8("action_New_variable_window"))
        self.action_Cascade = QtGui.QAction(MainWindow)
        self.action_Cascade.setObjectName(_fromUtf8("action_Cascade"))
        self.action_Tile_vertically = QtGui.QAction(MainWindow)
        self.action_Tile_vertically.setObjectName(_fromUtf8("action_Tile_vertically"))
        self.action_Tile_horizontally = QtGui.QAction(MainWindow)
        self.action_Tile_horizontally.setObjectName(_fromUtf8("action_Tile_horizontally"))
        self.action_list_format = QtGui.QAction(MainWindow)
        self.action_list_format.setObjectName(_fromUtf8("action_list_format"))
        self.action_delete_job = QtGui.QAction(MainWindow)
        self.action_delete_job.setEnabled(False)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8(":/Delete job")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_delete_job.setIcon(icon5)
        self.action_delete_job.setObjectName(_fromUtf8("action_delete_job"))
        self.action_JPermissions = QtGui.QAction(MainWindow)
        self.action_JPermissions.setEnabled(False)
        self.action_JPermissions.setObjectName(_fromUtf8("action_JPermissions"))
        self.action_titprill = QtGui.QAction(MainWindow)
        self.action_titprill.setEnabled(False)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(_fromUtf8(":/Title priority load level")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_titprill.setIcon(icon6)
        self.action_titprill.setObjectName(_fromUtf8("action_titprill"))
        self.action_set_runnable = QtGui.QAction(MainWindow)
        self.action_set_runnable.setEnabled(False)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(_fromUtf8(":/Set runnable")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_set_runnable.setIcon(icon7)
        self.action_set_runnable.setObjectName(_fromUtf8("action_set_runnable"))
        self.action_setcanc = QtGui.QAction(MainWindow)
        self.action_setcanc.setEnabled(False)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(_fromUtf8(":/Set cancelled")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_setcanc.setIcon(icon8)
        self.action_setcanc.setObjectName(_fromUtf8("action_setcanc"))
        self.action_interrupt_job = QtGui.QAction(MainWindow)
        self.action_interrupt_job.setEnabled(False)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(_fromUtf8(":/Interrupt signal")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_interrupt_job.setIcon(icon9)
        self.action_interrupt_job.setObjectName(_fromUtf8("action_interrupt_job"))
        self.action_quit_job = QtGui.QAction(MainWindow)
        self.action_quit_job.setEnabled(False)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(_fromUtf8(":/Quit signal")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_quit_job.setIcon(icon10)
        self.action_quit_job.setObjectName(_fromUtf8("action_quit_job"))
        self.action_othersig = QtGui.QAction(MainWindow)
        self.action_othersig.setEnabled(False)
        self.action_othersig.setObjectName(_fromUtf8("action_othersig"))
        self.action_View_job = QtGui.QAction(MainWindow)
        self.action_View_job.setEnabled(False)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(_fromUtf8(":/View job script")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_View_job.setIcon(icon11)
        self.action_View_job.setObjectName(_fromUtf8("action_View_job"))
        self.action_advance_time = QtGui.QAction(MainWindow)
        self.action_advance_time.setEnabled(False)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(_fromUtf8(":/Advance time")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_advance_time.setIcon(icon12)
        self.action_advance_time.setObjectName(_fromUtf8("action_advance_time"))
        self.action_time_limits = QtGui.QAction(MainWindow)
        self.action_time_limits.setEnabled(False)
        self.action_time_limits.setObjectName(_fromUtf8("action_time_limits"))
        self.action_procpar = QtGui.QAction(MainWindow)
        self.action_procpar.setEnabled(False)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(_fromUtf8(":/Process parameters")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_procpar.setIcon(icon13)
        self.action_procpar.setObjectName(_fromUtf8("action_procpar"))
        self.action_time = QtGui.QAction(MainWindow)
        self.action_time.setEnabled(False)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(_fromUtf8(":/Set time")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_time.setIcon(icon14)
        self.action_time.setObjectName(_fromUtf8("action_time"))
        self.action_mailwrt = QtGui.QAction(MainWindow)
        self.action_mailwrt.setEnabled(False)
        self.action_mailwrt.setObjectName(_fromUtf8("action_mailwrt"))
        self.action_Unqueue_job = QtGui.QAction(MainWindow)
        self.action_Unqueue_job.setObjectName(_fromUtf8("action_Unqueue_job"))
        self.action_Search_for = QtGui.QAction(MainWindow)
        self.action_Search_for.setObjectName(_fromUtf8("action_Search_for"))
        self.action_Search_forwards = QtGui.QAction(MainWindow)
        self.action_Search_forwards.setObjectName(_fromUtf8("action_Search_forwards"))
        self.action_Search_Backwards = QtGui.QAction(MainWindow)
        self.action_Search_Backwards.setObjectName(_fromUtf8("action_Search_Backwards"))
        self.action_About_BTQW = QtGui.QAction(MainWindow)
        self.action_About_BTQW.setObjectName(_fromUtf8("action_About_BTQW"))
        self.action_force_run = QtGui.QAction(MainWindow)
        self.action_force_run.setEnabled(False)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(_fromUtf8(":/Force run")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_force_run.setIcon(icon15)
        self.action_force_run.setObjectName(_fromUtf8("action_force_run"))
        self.action_Server_list = QtGui.QAction(MainWindow)
        self.action_Server_list.setObjectName(_fromUtf8("action_Server_list"))
        self.action_Port_settings = QtGui.QAction(MainWindow)
        self.action_Port_settings.setObjectName(_fromUtf8("action_Port_settings"))
        self.action_Save_As = QtGui.QAction(MainWindow)
        self.action_Save_As.setObjectName(_fromUtf8("action_Save_As"))
        self.action_Time_defaults = QtGui.QAction(MainWindow)
        self.action_Time_defaults.setObjectName(_fromUtf8("action_Time_defaults"))
        self.action_Condition_defaults = QtGui.QAction(MainWindow)
        self.action_Condition_defaults.setObjectName(_fromUtf8("action_Condition_defaults"))
        self.action_Assignment_defaults = QtGui.QAction(MainWindow)
        self.action_Assignment_defaults.setObjectName(_fromUtf8("action_Assignment_defaults"))
        self.action_go_job = QtGui.QAction(MainWindow)
        self.action_go_job.setEnabled(False)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(_fromUtf8(":/Go job")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_go_job.setIcon(icon16)
        self.action_go_job.setObjectName(_fromUtf8("action_go_job"))
        self.action_Arguments = QtGui.QAction(MainWindow)
        self.action_Arguments.setEnabled(False)
        self.action_Arguments.setObjectName(_fromUtf8("action_Arguments"))
        self.action_Environment = QtGui.QAction(MainWindow)
        self.action_Environment.setEnabled(False)
        self.action_Environment.setObjectName(_fromUtf8("action_Environment"))
        self.action_Redirections = QtGui.QAction(MainWindow)
        self.action_Redirections.setEnabled(False)
        self.action_Redirections.setObjectName(_fromUtf8("action_Redirections"))
        self.action_Invoke_BTRW = QtGui.QAction(MainWindow)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(_fromUtf8(":/Btrw icon")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Invoke_BTRW.setIcon(icon17)
        self.action_Invoke_BTRW.setObjectName(_fromUtf8("action_Invoke_BTRW"))
        self.action_Unqueue_Job = QtGui.QAction(MainWindow)
        self.action_Unqueue_Job.setEnabled(False)
        self.action_Unqueue_Job.setObjectName(_fromUtf8("action_Unqueue_Job"))
        self.action_Copy_Job = QtGui.QAction(MainWindow)
        self.action_Copy_Job.setEnabled(False)
        self.action_Copy_Job.setObjectName(_fromUtf8("action_Copy_Job"))
        self.action_Job_Conditions = QtGui.QAction(MainWindow)
        self.action_Job_Conditions.setEnabled(False)
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(_fromUtf8(":/Job conditions")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Job_Conditions.setIcon(icon18)
        self.action_Job_Conditions.setObjectName(_fromUtf8("action_Job_Conditions"))
        self.action_Job_Assignments = QtGui.QAction(MainWindow)
        self.action_Job_Assignments.setEnabled(False)
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(_fromUtf8(":/Job assignments")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Job_Assignments.setIcon(icon19)
        self.action_Job_Assignments.setObjectName(_fromUtf8("action_Job_Assignments"))
        self.action_Assign = QtGui.QAction(MainWindow)
        self.action_Assign.setEnabled(False)
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(_fromUtf8(":/Assign var")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Assign.setIcon(icon20)
        self.action_Assign.setObjectName(_fromUtf8("action_Assign"))
        self.action_Increment = QtGui.QAction(MainWindow)
        self.action_Increment.setEnabled(False)
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap(_fromUtf8(":/Increment var")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Increment.setIcon(icon21)
        self.action_Increment.setObjectName(_fromUtf8("action_Increment"))
        self.action_Decrement = QtGui.QAction(MainWindow)
        self.action_Decrement.setEnabled(False)
        icon22 = QtGui.QIcon()
        icon22.addPixmap(QtGui.QPixmap(_fromUtf8(":/Decrement var")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Decrement.setIcon(icon22)
        self.action_Decrement.setObjectName(_fromUtf8("action_Decrement"))
        self.action_Multiply = QtGui.QAction(MainWindow)
        self.action_Multiply.setEnabled(False)
        self.action_Multiply.setObjectName(_fromUtf8("action_Multiply"))
        self.action_Divide = QtGui.QAction(MainWindow)
        self.action_Divide.setEnabled(False)
        self.action_Divide.setObjectName(_fromUtf8("action_Divide"))
        self.action_Remainder = QtGui.QAction(MainWindow)
        self.action_Remainder.setEnabled(False)
        self.action_Remainder.setObjectName(_fromUtf8("action_Remainder"))
        self.action_Set_comment = QtGui.QAction(MainWindow)
        self.action_Set_comment.setEnabled(False)
        self.action_Set_comment.setObjectName(_fromUtf8("action_Set_comment"))
        self.action_Set_constant = QtGui.QAction(MainWindow)
        self.action_Set_constant.setObjectName(_fromUtf8("action_Set_constant"))
        self.action_VPermissions = QtGui.QAction(MainWindow)
        self.action_VPermissions.setEnabled(False)
        self.action_VPermissions.setObjectName(_fromUtf8("action_VPermissions"))
        self.action_Create_Jobs = QtGui.QAction(MainWindow)
        self.action_Create_Jobs.setObjectName(_fromUtf8("action_Create_Jobs"))
        self.action_Create_Variable = QtGui.QAction(MainWindow)
        self.action_Create_Variable.setObjectName(_fromUtf8("action_Create_Variable"))
        self.action_Delete_Job = QtGui.QAction(MainWindow)
        self.action_Delete_Job.setObjectName(_fromUtf8("action_Delete_Job"))
        self.action_Delete_Variable = QtGui.QAction(MainWindow)
        self.action_Delete_Variable.setEnabled(False)
        self.action_Delete_Variable.setObjectName(_fromUtf8("action_Delete_Variable"))
        self.menu_File.addAction(self.action_Time_defaults)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Program_options)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Server_list)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Port_settings)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Save_As)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Quit)
        self.menu_Window.addAction(self.action_New_job_window)
        self.menu_Window.addAction(self.action_New_variable_window)
        self.menu_Window.addAction(self.action_Window_options)
        self.menu_Window.addSeparator()
        self.menu_Window.addAction(self.action_Cascade)
        self.menu_Window.addAction(self.action_Tile_vertically)
        self.menu_Window.addAction(self.action_Tile_horizontally)
        self.menu_Window.addSeparator()
        self.menu_Window.addAction(self.action_list_format)
        self.menu_Action.addSeparator()
        self.menu_Action.addAction(self.action_set_runnable)
        self.menu_Action.addAction(self.action_setcanc)
        self.menu_Action.addAction(self.action_force_run)
        self.menu_Action.addAction(self.action_go_job)
        self.menu_Action.addAction(self.action_interrupt_job)
        self.menu_Action.addAction(self.action_quit_job)
        self.menu_Action.addAction(self.action_othersig)
        self.menu_Jobs.addAction(self.action_View_job)
        self.menu_Jobs.addSeparator()
        self.menu_Jobs.addAction(self.action_advance_time)
        self.menu_Jobs.addSeparator()
        self.menu_Jobs.addAction(self.action_time)
        self.menu_Jobs.addAction(self.action_titprill)
        self.menu_Jobs.addAction(self.action_procpar)
        self.menu_Jobs.addAction(self.action_time_limits)
        self.menu_Jobs.addAction(self.action_mailwrt)
        self.menu_Jobs.addSeparator()
        self.menu_Jobs.addAction(self.action_Arguments)
        self.menu_Jobs.addAction(self.action_Environment)
        self.menu_Jobs.addAction(self.action_Redirections)
        self.menu_Jobs.addSeparator()
        self.menu_Jobs.addAction(self.action_Unqueue_Job)
        self.menu_Jobs.addAction(self.action_Copy_Job)
        self.menu_Jobs.addSeparator()
        self.menu_Conds.addAction(self.action_Job_Conditions)
        self.menu_Conds.addAction(self.action_Job_Assignments)
        self.menu_Search.addAction(self.action_Search_for)
        self.menu_Search.addAction(self.action_Search_forwards)
        self.menu_Search.addAction(self.action_Search_Backwards)
        self.menu_Help.addAction(self.action_About_BTQW)
        self.menu_Variables.addAction(self.action_Assign)
        self.menu_Variables.addAction(self.action_Increment)
        self.menu_Variables.addAction(self.action_Decrement)
        self.menu_Variables.addAction(self.action_Multiply)
        self.menu_Variables.addAction(self.action_Divide)
        self.menu_Variables.addAction(self.action_Remainder)
        self.menu_Variables.addSeparator()
        self.menu_Variables.addAction(self.action_Set_comment)
        self.menu_Variables.addSeparator()
        self.menu_Variables.addAction(self.action_Set_constant)
        self.menuCreate.addAction(self.action_Create_Jobs)
        self.menuCreate.addAction(self.action_delete_job)
        self.menuCreate.addAction(self.action_JPermissions)
        self.menuCreate.addSeparator()
        self.menuCreate.addAction(self.action_Create_Variable)
        self.menuCreate.addAction(self.action_Delete_Variable)
        self.menuCreate.addAction(self.action_VPermissions)
        self.menubar.addAction(self.menu_File.menuAction())
        self.menubar.addAction(self.menu_Window.menuAction())
        self.menubar.addAction(self.menu_Action.menuAction())
        self.menubar.addAction(self.menuCreate.menuAction())
        self.menubar.addAction(self.menu_Jobs.menuAction())
        self.menubar.addAction(self.menu_Conds.menuAction())
        self.menubar.addAction(self.menu_Variables.menuAction())
        self.menubar.addAction(self.menu_Search.menuAction())
        self.menubar.addAction(self.menu_Help.menuAction())
        self.toolBar.addAction(self.action_Program_options)
        self.toolBar.addAction(self.action_Window_options)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_View_job)
        self.toolBar.addAction(self.action_titprill)
        self.toolBar.addAction(self.action_procpar)
        self.toolBar.addAction(self.action_delete_job)
        self.toolBar.addAction(self.action_set_runnable)
        self.toolBar.addAction(self.action_setcanc)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_force_run)
        self.toolBar.addAction(self.action_go_job)
        self.toolBar.addAction(self.action_advance_time)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_interrupt_job)
        self.toolBar.addAction(self.action_quit_job)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_time)
        self.toolBar.addAction(self.action_Job_Conditions)
        self.toolBar.addAction(self.action_Job_Assignments)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_Assign)
        self.toolBar.addAction(self.action_Increment)
        self.toolBar.addAction(self.action_Decrement)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "BTQW", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_File.setTitle(QtGui.QApplication.translate("MainWindow", "&File", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Window.setTitle(QtGui.QApplication.translate("MainWindow", "&Window", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Action.setTitle(QtGui.QApplication.translate("MainWindow", "&Action", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Jobs.setTitle(QtGui.QApplication.translate("MainWindow", "&Jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Conds.setTitle(QtGui.QApplication.translate("MainWindow", "&Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Search.setTitle(QtGui.QApplication.translate("MainWindow", "&Search", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Help.setTitle(QtGui.QApplication.translate("MainWindow", "&Help", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Variables.setTitle(QtGui.QApplication.translate("MainWindow", "&Variables", None, QtGui.QApplication.UnicodeUTF8))
        self.menuCreate.setTitle(QtGui.QApplication.translate("MainWindow", "Create/Delete", None, QtGui.QApplication.UnicodeUTF8))
        self.toolBar.setWindowTitle(QtGui.QApplication.translate("MainWindow", "toolBar", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Program_options.setText(QtGui.QApplication.translate("MainWindow", "&Program options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Program_options.setToolTip(QtGui.QApplication.translate("MainWindow", "Set overall program options, confirmation of job abort etc", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Program_options.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+P", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Display_options.setText(QtGui.QApplication.translate("MainWindow", "&Display options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Display_options.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the defaults for which items are displayed", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Display_options.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+D", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_options.setText(QtGui.QApplication.translate("MainWindow", "&Save options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_options.setToolTip(QtGui.QApplication.translate("MainWindow", "Save options to config file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_options.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+S", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Network_stats.setText(QtGui.QApplication.translate("MainWindow", "&Network stats", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Network_stats.setToolTip(QtGui.QApplication.translate("MainWindow", "Display connection statistics to other hosts on network", None, QtGui.QApplication.UnicodeUTF8))
        self.action_User_Permissions.setText(QtGui.QApplication.translate("MainWindow", "&User Permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_User_Permissions.setToolTip(QtGui.QApplication.translate("MainWindow", "Display user permissions on the current server", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Quit.setText(QtGui.QApplication.translate("MainWindow", "&Quit", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Quit.setToolTip(QtGui.QApplication.translate("MainWindow", "Quit saving program options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Quit.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Q", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Window_options.setText(QtGui.QApplication.translate("MainWindow", "&Window Options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Window_options.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+O", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_job_window.setText(QtGui.QApplication.translate("MainWindow", "New &job window", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_job_window.setToolTip(QtGui.QApplication.translate("MainWindow", "Create new job window (you can separately change viewing options)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_job_window.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Shift+J", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_variable_window.setText(QtGui.QApplication.translate("MainWindow", "New &variable window", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_variable_window.setToolTip(QtGui.QApplication.translate("MainWindow", "Create new variable display window (you can separately change viewing options)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_variable_window.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Shift+V", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Cascade.setText(QtGui.QApplication.translate("MainWindow", "&Cascade", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Cascade.setToolTip(QtGui.QApplication.translate("MainWindow", "Cascade job and variable windows", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Tile_vertically.setText(QtGui.QApplication.translate("MainWindow", "&Tile vertically", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Tile_vertically.setToolTip(QtGui.QApplication.translate("MainWindow", "Tile job and variable windows vertically", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Tile_horizontally.setText(QtGui.QApplication.translate("MainWindow", "&Tile horizontally", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Tile_horizontally.setToolTip(QtGui.QApplication.translate("MainWindow", "Tile job and variable windows horizontally", None, QtGui.QApplication.UnicodeUTF8))
        self.action_list_format.setText(QtGui.QApplication.translate("MainWindow", "&Set list format", None, QtGui.QApplication.UnicodeUTF8))
        self.action_list_format.setToolTip(QtGui.QApplication.translate("MainWindow", "Set which attributes of jobs or variables you want displayed in currently-selected window", None, QtGui.QApplication.UnicodeUTF8))
        self.action_delete_job.setText(QtGui.QApplication.translate("MainWindow", "&Delete Job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_delete_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Delete job (which should not be running - kill it first)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_delete_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Del", None, QtGui.QApplication.UnicodeUTF8))
        self.action_JPermissions.setText(QtGui.QApplication.translate("MainWindow", "Job &Permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_JPermissions.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the permissions on the selected job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_titprill.setText(QtGui.QApplication.translate("MainWindow", "&Title prio, load level", None, QtGui.QApplication.UnicodeUTF8))
        self.action_titprill.setToolTip(QtGui.QApplication.translate("MainWindow", "Set title, priority, load level, command interpreter", None, QtGui.QApplication.UnicodeUTF8))
        self.action_titprill.setShortcut(QtGui.QApplication.translate("MainWindow", "P", None, QtGui.QApplication.UnicodeUTF8))
        self.action_set_runnable.setText(QtGui.QApplication.translate("MainWindow", "Set &runnable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_set_runnable.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the job to be runnable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_set_runnable.setShortcut(QtGui.QApplication.translate("MainWindow", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.action_setcanc.setText(QtGui.QApplication.translate("MainWindow", "Set &cancelled", None, QtGui.QApplication.UnicodeUTF8))
        self.action_setcanc.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the job to cancelled state (does not activate cancelled assignment)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_setcanc.setShortcut(QtGui.QApplication.translate("MainWindow", "Z", None, QtGui.QApplication.UnicodeUTF8))
        self.action_interrupt_job.setText(QtGui.QApplication.translate("MainWindow", "&Interrupt job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_interrupt_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Send \"interrupt\" signal to job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_interrupt_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+Y", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit_job.setText(QtGui.QApplication.translate("MainWindow", "&Quit job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Send \"quit\" signal to job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+N", None, QtGui.QApplication.UnicodeUTF8))
        self.action_othersig.setText(QtGui.QApplication.translate("MainWindow", "&Other signal", None, QtGui.QApplication.UnicodeUTF8))
        self.action_othersig.setToolTip(QtGui.QApplication.translate("MainWindow", "Send selected signal to job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_othersig.setShortcut(QtGui.QApplication.translate("MainWindow", "!", None, QtGui.QApplication.UnicodeUTF8))
        self.action_View_job.setText(QtGui.QApplication.translate("MainWindow", "&View job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_View_job.setToolTip(QtGui.QApplication.translate("MainWindow", "View the job script in a new window", None, QtGui.QApplication.UnicodeUTF8))
        self.action_View_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+I", None, QtGui.QApplication.UnicodeUTF8))
        self.action_advance_time.setText(QtGui.QApplication.translate("MainWindow", "&Advance Time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_advance_time.setToolTip(QtGui.QApplication.translate("MainWindow", "Advance time of job to next repeat time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_advance_time.setShortcut(QtGui.QApplication.translate("MainWindow", "F", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time_limits.setText(QtGui.QApplication.translate("MainWindow", "Time &limits", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time_limits.setToolTip(QtGui.QApplication.translate("MainWindow", "Set time limits and automatic signal to job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time_limits.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+L", None, QtGui.QApplication.UnicodeUTF8))
        self.action_procpar.setText(QtGui.QApplication.translate("MainWindow", "&Process Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.action_procpar.setToolTip(QtGui.QApplication.translate("MainWindow", "Set process parameters (umask, directory etc) on job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_procpar.setShortcut(QtGui.QApplication.translate("MainWindow", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time.setText(QtGui.QApplication.translate("MainWindow", "&Time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time.setIconText(QtGui.QApplication.translate("MainWindow", "Time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time.setToolTip(QtGui.QApplication.translate("MainWindow", "Set next time and repeat parameters on job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time.setShortcut(QtGui.QApplication.translate("MainWindow", "T", None, QtGui.QApplication.UnicodeUTF8))
        self.action_mailwrt.setText(QtGui.QApplication.translate("MainWindow", "&Mail and write", None, QtGui.QApplication.UnicodeUTF8))
        self.action_mailwrt.setToolTip(QtGui.QApplication.translate("MainWindow", "Set user and message completion options on job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_mailwrt.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+M", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_job.setText(QtGui.QApplication.translate("MainWindow", "Un&queue job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Take job off the queue and make a re-queueable file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+U", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_for.setText(QtGui.QApplication.translate("MainWindow", "&Search for...", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_for.setToolTip(QtGui.QApplication.translate("MainWindow", "Search for a string in current window", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_for.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+F", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_forwards.setText(QtGui.QApplication.translate("MainWindow", "Search &forwards", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_forwards.setToolTip(QtGui.QApplication.translate("MainWindow", "Repeat last search going forwards", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_forwards.setShortcut(QtGui.QApplication.translate("MainWindow", "F3, Ctrl+G", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_Backwards.setText(QtGui.QApplication.translate("MainWindow", "Search &backwards", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_Backwards.setToolTip(QtGui.QApplication.translate("MainWindow", "Repeat last search going backwards", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_Backwards.setShortcut(QtGui.QApplication.translate("MainWindow", "F4", None, QtGui.QApplication.UnicodeUTF8))
        self.action_About_BTQW.setText(QtGui.QApplication.translate("MainWindow", "&About BTQW", None, QtGui.QApplication.UnicodeUTF8))
        self.action_About_BTQW.setIconText(QtGui.QApplication.translate("MainWindow", "About BTQW", None, QtGui.QApplication.UnicodeUTF8))
        self.action_force_run.setText(QtGui.QApplication.translate("MainWindow", "&Force run", None, QtGui.QApplication.UnicodeUTF8))
        self.action_force_run.setToolTip(QtGui.QApplication.translate("MainWindow", "Set job runnable if not and try to force it to run, bypassing the time setting\n"
"(but not the conditions)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Server_list.setText(QtGui.QApplication.translate("MainWindow", "&Server list", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Server_list.setToolTip(QtGui.QApplication.translate("MainWindow", "Display list of servers and connection status", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Port_settings.setText(QtGui.QApplication.translate("MainWindow", "P&ort settings", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Port_settings.setToolTip(QtGui.QApplication.translate("MainWindow", "Adjust port settings for access (use with care)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_As.setText(QtGui.QApplication.translate("MainWindow", "Save &As...", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_As.setToolTip(QtGui.QApplication.translate("MainWindow", "Specify an alternative saved configuration file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_As.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Shift+S", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Time_defaults.setText(QtGui.QApplication.translate("MainWindow", "&Time defaults", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Condition_defaults.setText(QtGui.QApplication.translate("MainWindow", "&Condition defaults", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Condition_defaults.setToolTip(QtGui.QApplication.translate("MainWindow", "Set default condition parameters for creating new conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assignment_defaults.setText(QtGui.QApplication.translate("MainWindow", "&Assignment defaults", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assignment_defaults.setToolTip(QtGui.QApplication.translate("MainWindow", "Set default assignment parameters for creating new assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_go_job.setText(QtGui.QApplication.translate("MainWindow", "&Go job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_go_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Force job to run but advance the time to the next repeat if applicable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Arguments.setText(QtGui.QApplication.translate("MainWindow", "&Arguments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Arguments.setToolTip(QtGui.QApplication.translate("MainWindow", "Set command line arguments to pass to the job script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Arguments.setShortcut(QtGui.QApplication.translate("MainWindow", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Environment.setText(QtGui.QApplication.translate("MainWindow", "&Environment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Environment.setToolTip(QtGui.QApplication.translate("MainWindow", "Set environment variables to pass to the job script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Environment.setShortcut(QtGui.QApplication.translate("MainWindow", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Redirections.setText(QtGui.QApplication.translate("MainWindow", "&Redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Redirections.setToolTip(QtGui.QApplication.translate("MainWindow", "Set I/O redirections to pass to the job script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Redirections.setShortcut(QtGui.QApplication.translate("MainWindow", "I", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Invoke_BTRW.setText(QtGui.QApplication.translate("MainWindow", "&Invoke BTRW", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Invoke_BTRW.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+W", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_Job.setText(QtGui.QApplication.translate("MainWindow", "&Unqueue Job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_Job.setToolTip(QtGui.QApplication.translate("MainWindow", "Unqueue Job, making a copy in an XML file on the local disk", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_Job.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+U", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Copy_Job.setText(QtGui.QApplication.translate("MainWindow", "&Copy job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Copy_Job.setToolTip(QtGui.QApplication.translate("MainWindow", "Copy job to an XML file on the local disk but do not delete the job.", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Copy_Job.setShortcut(QtGui.QApplication.translate("MainWindow", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Conditions.setText(QtGui.QApplication.translate("MainWindow", "Job &Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Conditions.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the Job Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Conditions.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+C", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Assignments.setText(QtGui.QApplication.translate("MainWindow", "Job &Assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Assignments.setToolTip(QtGui.QApplication.translate("MainWindow", "Set Job Assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Assignments.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+A", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assign.setText(QtGui.QApplication.translate("MainWindow", "&Assign", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assign.setToolTip(QtGui.QApplication.translate("MainWindow", "Assign a given value to the variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assign.setShortcut(QtGui.QApplication.translate("MainWindow", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Increment.setText(QtGui.QApplication.translate("MainWindow", "&Increment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Increment.setToolTip(QtGui.QApplication.translate("MainWindow", "Increment variable by the amount given in the set constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Increment.setShortcut(QtGui.QApplication.translate("MainWindow", "+", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Decrement.setText(QtGui.QApplication.translate("MainWindow", "&Decrement", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Decrement.setToolTip(QtGui.QApplication.translate("MainWindow", "Decrement variable by amount given in the set constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Decrement.setShortcut(QtGui.QApplication.translate("MainWindow", "-", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Multiply.setText(QtGui.QApplication.translate("MainWindow", "&Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Multiply.setToolTip(QtGui.QApplication.translate("MainWindow", "Multiply variable by amount given in set constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Multiply.setShortcut(QtGui.QApplication.translate("MainWindow", "*", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Divide.setText(QtGui.QApplication.translate("MainWindow", "&Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Divide.setToolTip(QtGui.QApplication.translate("MainWindow", "Divide variable by amount given in set constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Divide.setShortcut(QtGui.QApplication.translate("MainWindow", "/", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Remainder.setText(QtGui.QApplication.translate("MainWindow", "&Remainder", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Remainder.setToolTip(QtGui.QApplication.translate("MainWindow", "Replace variable value by remainder when divided by set constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Remainder.setShortcut(QtGui.QApplication.translate("MainWindow", "%", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_comment.setText(QtGui.QApplication.translate("MainWindow", "&Set comment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_comment.setToolTip(QtGui.QApplication.translate("MainWindow", "Set comment on variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_comment.setShortcut(QtGui.QApplication.translate("MainWindow", "\"", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_constant.setText(QtGui.QApplication.translate("MainWindow", "Set &constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_constant.setToolTip(QtGui.QApplication.translate("MainWindow", "Set constant to use in arithmetic operations", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_constant.setShortcut(QtGui.QApplication.translate("MainWindow", "@", None, QtGui.QApplication.UnicodeUTF8))
        self.action_VPermissions.setText(QtGui.QApplication.translate("MainWindow", "Variable &Permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_VPermissions.setToolTip(QtGui.QApplication.translate("MainWindow", "Set permissions on the selected variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Create_Jobs.setText(QtGui.QApplication.translate("MainWindow", "Create &Jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Create_Jobs.setToolTip(QtGui.QApplication.translate("MainWindow", "Enter window for creating jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Create_Jobs.setStatusTip(QtGui.QApplication.translate("MainWindow", "This option invokes the BTRW program", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Create_Variable.setText(QtGui.QApplication.translate("MainWindow", "Create &Variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Create_Variable.setToolTip(QtGui.QApplication.translate("MainWindow", "Create a Variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Delete_Job.setText(QtGui.QApplication.translate("MainWindow", "Delete Job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Delete_Job.setToolTip(QtGui.QApplication.translate("MainWindow", "Delete currently-selected Job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Delete_Variable.setText(QtGui.QApplication.translate("MainWindow", "Delete Variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Delete_Variable.setToolTip(QtGui.QApplication.translate("MainWindow", "Delete Currently-selected Variable", None, QtGui.QApplication.UnicodeUTF8))

import resources_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mailwrtdlg.ui'
#
# Created: Fri Nov 16 09:49:02 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_mailwrtdlg(object):
    def setupUi(self, mailwrtdlg):
        mailwrtdlg.setObjectName(_fromUtf8("mailwrtdlg"))
        mailwrtdlg.resize(400, 300)
        self.buttonBox = QtGui.QDialogButtonBox(mailwrtdlg)
        self.buttonBox.setGeometry(QtCore.QRect(170, 240, 201, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.mailresult = QtGui.QCheckBox(mailwrtdlg)
        self.mailresult.setGeometry(QtCore.QRect(40, 110, 221, 22))
        self.mailresult.setObjectName(_fromUtf8("mailresult"))
        self.writeresult = QtGui.QCheckBox(mailwrtdlg)
        self.writeresult.setGeometry(QtCore.QRect(40, 180, 261, 22))
        self.writeresult.setObjectName(_fromUtf8("writeresult"))
        self.edjob = QtGui.QLabel(mailwrtdlg)
        self.edjob.setGeometry(QtCore.QRect(130, 40, 191, 20))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label = QtGui.QLabel(mailwrtdlg)
        self.label.setGeometry(QtCore.QRect(20, 40, 81, 17))
        self.label.setObjectName(_fromUtf8("label"))

        self.retranslateUi(mailwrtdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), mailwrtdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), mailwrtdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(mailwrtdlg)
        mailwrtdlg.setTabOrder(self.mailresult, self.writeresult)
        mailwrtdlg.setTabOrder(self.writeresult, self.buttonBox)

    def retranslateUi(self, mailwrtdlg):
        mailwrtdlg.setWindowTitle(QtGui.QApplication.translate("mailwrtdlg", "Mail or display completion messages", None, QtGui.QApplication.UnicodeUTF8))
        self.mailresult.setToolTip(QtGui.QApplication.translate("mailwrtdlg", "Send mail messages to user about job completion", None, QtGui.QApplication.UnicodeUTF8))
        self.mailresult.setText(QtGui.QApplication.translate("mailwrtdlg", "Mail completion message", None, QtGui.QApplication.UnicodeUTF8))
        self.writeresult.setToolTip(QtGui.QApplication.translate("mailwrtdlg", "Send messages to user screen about job completion", None, QtGui.QApplication.UnicodeUTF8))
        self.writeresult.setText(QtGui.QApplication.translate("mailwrtdlg", "Display completion message", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("mailwrtdlg", "Editing job:", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jobeditdlg.ui'
#
# Created: Tue Jan 22 17:58:40 2013
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jobeditdlg(object):
    def setupUi(self, jobeditdlg):
        jobeditdlg.setObjectName(_fromUtf8("jobeditdlg"))
        jobeditdlg.resize(877, 625)
        self.buttonBox = QtGui.QDialogButtonBox(jobeditdlg)
        self.buttonBox.setGeometry(QtCore.QRect(620, 580, 201, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.widget = QtGui.QWidget(jobeditdlg)
        self.widget.setGeometry(QtCore.QRect(11, 11, 851, 561))
        self.widget.setObjectName(_fromUtf8("widget"))
        self.gridLayout = QtGui.QGridLayout(self.widget)
        self.gridLayout.setMargin(0)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.label = QtGui.QLabel(self.widget)
        self.label.setObjectName(_fromUtf8("label"))
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.jobdescr = QtGui.QLineEdit(self.widget)
        self.jobdescr.setReadOnly(True)
        self.jobdescr.setObjectName(_fromUtf8("jobdescr"))
        self.gridLayout.addWidget(self.jobdescr, 0, 1, 1, 1)
        self.jobtext = QtGui.QPlainTextEdit(self.widget)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setPointSize(12)
        self.jobtext.setFont(font)
        self.jobtext.setObjectName(_fromUtf8("jobtext"))
        self.gridLayout.addWidget(self.jobtext, 1, 0, 1, 2)

        self.retranslateUi(jobeditdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jobeditdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jobeditdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jobeditdlg)
        jobeditdlg.setTabOrder(self.jobdescr, self.jobtext)
        jobeditdlg.setTabOrder(self.jobtext, self.buttonBox)

    def retranslateUi(self, jobeditdlg):
        jobeditdlg.setWindowTitle(QtGui.QApplication.translate("jobeditdlg", "Edit job script", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jobeditdlg", "Editing script for job", None, QtGui.QApplication.UnicodeUTF8))
        self.jobtext.setToolTip(QtGui.QApplication.translate("jobeditdlg", "This is the script of the job for the given command interpreter", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jenvsdlg.ui'
#
# Created: Tue Nov 20 09:31:20 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jenvsdlg(object):
    def setupUi(self, jenvsdlg):
        jenvsdlg.setObjectName(_fromUtf8("jenvsdlg"))
        jenvsdlg.resize(823, 407)
        self.buttonBox = QtGui.QDialogButtonBox(jenvsdlg)
        self.buttonBox.setGeometry(QtCore.QRect(610, 360, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edjob = QtGui.QLabel(jenvsdlg)
        self.edjob.setGeometry(QtCore.QRect(130, 30, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label = QtGui.QLabel(jenvsdlg)
        self.label.setGeometry(QtCore.QRect(30, 30, 91, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.envlist = QtGui.QListWidget(jenvsdlg)
        self.envlist.setGeometry(QtCore.QRect(30, 70, 771, 192))
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setPointSize(10)
        self.envlist.setFont(font)
        self.envlist.setDragDropMode(QtGui.QAbstractItemView.InternalMove)
        self.envlist.setObjectName(_fromUtf8("envlist"))
        self.newenv = QtGui.QPushButton(jenvsdlg)
        self.newenv.setGeometry(QtCore.QRect(30, 300, 98, 27))
        self.newenv.setObjectName(_fromUtf8("newenv"))
        self.delenv = QtGui.QPushButton(jenvsdlg)
        self.delenv.setGeometry(QtCore.QRect(700, 300, 98, 27))
        self.delenv.setObjectName(_fromUtf8("delenv"))

        self.retranslateUi(jenvsdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jenvsdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jenvsdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jenvsdlg)
        jenvsdlg.setTabOrder(self.envlist, self.newenv)
        jenvsdlg.setTabOrder(self.newenv, self.delenv)
        jenvsdlg.setTabOrder(self.delenv, self.buttonBox)

    def retranslateUi(self, jenvsdlg):
        jenvsdlg.setWindowTitle(QtGui.QApplication.translate("jenvsdlg", "Environment Variable List", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jenvsdlg", "Env for job:", None, QtGui.QApplication.UnicodeUTF8))
        self.envlist.setToolTip(QtGui.QApplication.translate("jenvsdlg", "These are the environment variables for the job.\n"
"\n"
"Drag and drop to re-order.\n"
"\n"
"Double-click to edit\n"
"\n"
"Click \"New\" to add a new environment variable.\n"
"\n"
"Select an item and press \"Delete\" to delete an environment variable.", None, QtGui.QApplication.UnicodeUTF8))
        self.newenv.setToolTip(QtGui.QApplication.translate("jenvsdlg", "Click this to add a new environment variable", None, QtGui.QApplication.UnicodeUTF8))
        self.newenv.setText(QtGui.QApplication.translate("jenvsdlg", "New", None, QtGui.QApplication.UnicodeUTF8))
        self.delenv.setToolTip(QtGui.QApplication.translate("jenvsdlg", "Press this to delete the currently-selected environment variable.", None, QtGui.QApplication.UnicodeUTF8))
        self.delenv.setText(QtGui.QApplication.translate("jenvsdlg", "Delete", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'timeparam.ui'
#
# Created: Mon Feb  4 20:08:19 2013
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_timeparamdlg(object):
    def setupUi(self, timeparamdlg):
        timeparamdlg.setObjectName(_fromUtf8("timeparamdlg"))
        timeparamdlg.resize(682, 516)
        self.buttonBox = QtGui.QDialogButtonBox(timeparamdlg)
        self.buttonBox.setGeometry(QtCore.QRect(400, 470, 261, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.timeisset = QtGui.QCheckBox(timeparamdlg)
        self.timeisset.setGeometry(QtCore.QRect(20, 20, 141, 22))
        self.timeisset.setObjectName(_fromUtf8("timeisset"))
        self.nexttime_date = QtGui.QCalendarWidget(timeparamdlg)
        self.nexttime_date.setGeometry(QtCore.QRect(20, 60, 448, 172))
        self.nexttime_date.setObjectName(_fromUtf8("nexttime_date"))
        self.nexttime_time = QtGui.QTimeEdit(timeparamdlg)
        self.nexttime_time.setGeometry(QtCore.QRect(490, 130, 118, 27))
        self.nexttime_time.setCalendarPopup(False)
        self.nexttime_time.setObjectName(_fromUtf8("nexttime_time"))
        self.label = QtGui.QLabel(timeparamdlg)
        self.label.setGeometry(QtCore.QRect(490, 80, 121, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.repstyle = QtGui.QComboBox(timeparamdlg)
        self.repstyle.setGeometry(QtCore.QRect(200, 270, 261, 27))
        self.repstyle.setObjectName(_fromUtf8("repstyle"))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repunits = QtGui.QSpinBox(timeparamdlg)
        self.repunits.setGeometry(QtCore.QRect(70, 270, 60, 27))
        self.repunits.setMinimum(1)
        self.repunits.setMaximum(60)
        self.repunits.setProperty("value", 1)
        self.repunits.setObjectName(_fromUtf8("repunits"))
        self.monthday = QtGui.QSpinBox(timeparamdlg)
        self.monthday.setGeometry(QtCore.QRect(500, 270, 60, 27))
        self.monthday.setMinimum(0)
        self.monthday.setMaximum(31)
        self.monthday.setSingleStep(1)
        self.monthday.setProperty("value", 1)
        self.monthday.setObjectName(_fromUtf8("monthday"))
        self.groupBox = QtGui.QGroupBox(timeparamdlg)
        self.groupBox.setGeometry(QtCore.QRect(70, 310, 411, 91))
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.avSun = QtGui.QCheckBox(self.groupBox)
        self.avSun.setGeometry(QtCore.QRect(0, 30, 97, 22))
        self.avSun.setObjectName(_fromUtf8("avSun"))
        self.avMon = QtGui.QCheckBox(self.groupBox)
        self.avMon.setGeometry(QtCore.QRect(90, 30, 97, 22))
        self.avMon.setObjectName(_fromUtf8("avMon"))
        self.avTue = QtGui.QCheckBox(self.groupBox)
        self.avTue.setGeometry(QtCore.QRect(180, 30, 97, 22))
        self.avTue.setObjectName(_fromUtf8("avTue"))
        self.avWed = QtGui.QCheckBox(self.groupBox)
        self.avWed.setGeometry(QtCore.QRect(270, 30, 111, 22))
        self.avWed.setObjectName(_fromUtf8("avWed"))
        self.avThu = QtGui.QCheckBox(self.groupBox)
        self.avThu.setGeometry(QtCore.QRect(0, 60, 97, 22))
        self.avThu.setObjectName(_fromUtf8("avThu"))
        self.avFri = QtGui.QCheckBox(self.groupBox)
        self.avFri.setGeometry(QtCore.QRect(90, 60, 97, 22))
        self.avFri.setObjectName(_fromUtf8("avFri"))
        self.avSat = QtGui.QCheckBox(self.groupBox)
        self.avSat.setGeometry(QtCore.QRect(180, 60, 97, 22))
        self.avSat.setObjectName(_fromUtf8("avSat"))
        self.avHol = QtGui.QCheckBox(self.groupBox)
        self.avHol.setGeometry(QtCore.QRect(270, 60, 97, 22))
        self.avHol.setObjectName(_fromUtf8("avHol"))
        self.label_2 = QtGui.QLabel(timeparamdlg)
        self.label_2.setGeometry(QtCore.QRect(70, 420, 161, 17))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.nextrep = QtGui.QLabel(timeparamdlg)
        self.nextrep.setGeometry(QtCore.QRect(250, 420, 201, 21))
        self.nextrep.setObjectName(_fromUtf8("nextrep"))
        self.ifnposs = QtGui.QComboBox(timeparamdlg)
        self.ifnposs.setGeometry(QtCore.QRect(220, 450, 151, 27))
        self.ifnposs.setObjectName(_fromUtf8("ifnposs"))
        self.ifnposs.addItem(_fromUtf8(""))
        self.ifnposs.addItem(_fromUtf8(""))
        self.ifnposs.addItem(_fromUtf8(""))
        self.ifnposs.addItem(_fromUtf8(""))
        self.label_3 = QtGui.QLabel(timeparamdlg)
        self.label_3.setGeometry(QtCore.QRect(70, 460, 111, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.label_4 = QtGui.QLabel(timeparamdlg)
        self.label_4.setGeometry(QtCore.QRect(500, 240, 141, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.setnow = QtGui.QPushButton(timeparamdlg)
        self.setnow.setGeometry(QtCore.QRect(490, 180, 98, 27))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.setnow.setFont(font)
        self.setnow.setObjectName(_fromUtf8("setnow"))

        self.retranslateUi(timeparamdlg)
        self.repstyle.setCurrentIndex(1)
        self.ifnposs.setCurrentIndex(1)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), timeparamdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), timeparamdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(timeparamdlg)
        timeparamdlg.setTabOrder(self.timeisset, self.nexttime_date)
        timeparamdlg.setTabOrder(self.nexttime_date, self.nexttime_time)
        timeparamdlg.setTabOrder(self.nexttime_time, self.setnow)
        timeparamdlg.setTabOrder(self.setnow, self.repunits)
        timeparamdlg.setTabOrder(self.repunits, self.repstyle)
        timeparamdlg.setTabOrder(self.repstyle, self.monthday)
        timeparamdlg.setTabOrder(self.monthday, self.avSun)
        timeparamdlg.setTabOrder(self.avSun, self.avMon)
        timeparamdlg.setTabOrder(self.avMon, self.avTue)
        timeparamdlg.setTabOrder(self.avTue, self.avWed)
        timeparamdlg.setTabOrder(self.avWed, self.avThu)
        timeparamdlg.setTabOrder(self.avThu, self.avFri)
        timeparamdlg.setTabOrder(self.avFri, self.avSat)
        timeparamdlg.setTabOrder(self.avSat, self.avHol)
        timeparamdlg.setTabOrder(self.avHol, self.ifnposs)
        timeparamdlg.setTabOrder(self.ifnposs, self.buttonBox)

    def retranslateUi(self, timeparamdlg):
        timeparamdlg.setWindowTitle(QtGui.QApplication.translate("timeparamdlg", "Job Time parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.timeisset.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Indicate job has time set as opposed to being a \"do when possible\" job.", None, QtGui.QApplication.UnicodeUTF8))
        self.timeisset.setText(QtGui.QApplication.translate("timeparamdlg", "Job has time set", None, QtGui.QApplication.UnicodeUTF8))
        self.nexttime_date.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Select the date of the next run here", None, QtGui.QApplication.UnicodeUTF8))
        self.nexttime_time.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Select the time part of the next time here", None, QtGui.QApplication.UnicodeUTF8))
        self.nexttime_time.setDisplayFormat(QtGui.QApplication.translate("timeparamdlg", "HH:mm", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("timeparamdlg", "Next time to run", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set here what style of repeat you require.\n"
"Either set to delete at the end, to retain as \"done\" with manual reset or as\n"
"auto-repeat by the intervals given and number of units as given in the box.", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(0, QtGui.QApplication.translate("timeparamdlg", "Delete at end", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(1, QtGui.QApplication.translate("timeparamdlg", "Retain as done", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(2, QtGui.QApplication.translate("timeparamdlg", "Minutes", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(3, QtGui.QApplication.translate("timeparamdlg", "Hours", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(4, QtGui.QApplication.translate("timeparamdlg", "Days", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(5, QtGui.QApplication.translate("timeparamdlg", "Weeks", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(6, QtGui.QApplication.translate("timeparamdlg", "Months (relative to the beginning)", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(7, QtGui.QApplication.translate("timeparamdlg", "Months (relative to the end)", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(8, QtGui.QApplication.translate("timeparamdlg", "Years", None, QtGui.QApplication.UnicodeUTF8))
        self.repunits.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Number of units of the repeat given", None, QtGui.QApplication.UnicodeUTF8))
        self.monthday.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set the target day of the month for monthly repeats\n"
"\n"
"For month relative to the beginning repeats, this gives the target day of the\n"
"month. If this is not acceptable, then the following day is tried until acceptable.\n"
"\n"
"For month relative to the end repeats this gives the number of days back from\n"
"the end of the month, possibly zero days, so if the month has 31 days, 0 would\n"
"aim for 31st, 1 would aim for 30th and so on. If the day of the week thereby\n"
"selected is unacceptable the preceding day is tried until acceptable.\n"
"\n"
"Note that the display of month days in month relative to the end has been\n"
"changed relative to previous software hopefully to make it more\n"
"understandable.", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Select days to avoid when calculating repeat", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("timeparamdlg", "Avoiding days", None, QtGui.QApplication.UnicodeUTF8))
        self.avSun.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Sunday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avSun.setText(QtGui.QApplication.translate("timeparamdlg", "Sunday", None, QtGui.QApplication.UnicodeUTF8))
        self.avMon.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Monday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avMon.setText(QtGui.QApplication.translate("timeparamdlg", "Monday", None, QtGui.QApplication.UnicodeUTF8))
        self.avTue.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Tuesday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avTue.setText(QtGui.QApplication.translate("timeparamdlg", "Tuesday", None, QtGui.QApplication.UnicodeUTF8))
        self.avWed.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Wednesday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avWed.setText(QtGui.QApplication.translate("timeparamdlg", "Wednesday", None, QtGui.QApplication.UnicodeUTF8))
        self.avThu.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Thursday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avThu.setText(QtGui.QApplication.translate("timeparamdlg", "Thursday", None, QtGui.QApplication.UnicodeUTF8))
        self.avFri.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Friday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avFri.setText(QtGui.QApplication.translate("timeparamdlg", "Friday", None, QtGui.QApplication.UnicodeUTF8))
        self.avSat.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Saturday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avSat.setText(QtGui.QApplication.translate("timeparamdlg", "Saturday", None, QtGui.QApplication.UnicodeUTF8))
        self.avHol.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Avoid one of the table of holidays when calculating repeats.\n"
"", None, QtGui.QApplication.UnicodeUTF8))
        self.avHol.setText(QtGui.QApplication.translate("timeparamdlg", "Holiday", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("timeparamdlg", "Next repeat would be", None, QtGui.QApplication.UnicodeUTF8))
        self.nextrep.setToolTip(QtGui.QApplication.translate("timeparamdlg", "This is the estimated next repeat time", None, QtGui.QApplication.UnicodeUTF8))
        self.nextrep.setText(QtGui.QApplication.translate("timeparamdlg", "(n/a)", None, QtGui.QApplication.UnicodeUTF8))
        self.ifnposs.setItemText(0, QtGui.QApplication.translate("timeparamdlg", "Skip to next", None, QtGui.QApplication.UnicodeUTF8))
        self.ifnposs.setItemText(1, QtGui.QApplication.translate("timeparamdlg", "Delay current", None, QtGui.QApplication.UnicodeUTF8))
        self.ifnposs.setItemText(2, QtGui.QApplication.translate("timeparamdlg", "Delay and adjust", None, QtGui.QApplication.UnicodeUTF8))
        self.ifnposs.setItemText(3, QtGui.QApplication.translate("timeparamdlg", "Catch up", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("timeparamdlg", "If not possible", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("timeparamdlg", "D of M or from end", None, QtGui.QApplication.UnicodeUTF8))
        self.setnow.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Reset date and time to \"now\"", None, QtGui.QApplication.UnicodeUTF8))
        self.setnow.setText(QtGui.QApplication.translate("timeparamdlg", "Now", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jenvdlg.ui'
#
# Created: Tue Nov 20 09:31:20 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jenvdlg(object):
    def setupUi(self, jenvdlg):
        jenvdlg.setObjectName(_fromUtf8("jenvdlg"))
        jenvdlg.resize(909, 274)
        self.buttonBox = QtGui.QDialogButtonBox(jenvdlg)
        self.buttonBox.setGeometry(QtCore.QRect(660, 220, 221, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edjob = QtGui.QLabel(jenvdlg)
        self.edjob.setGeometry(QtCore.QRect(310, 50, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label = QtGui.QLabel(jenvdlg)
        self.label.setGeometry(QtCore.QRect(40, 50, 201, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.label_2 = QtGui.QLabel(jenvdlg)
        self.label_2.setGeometry(QtCore.QRect(40, 110, 66, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.label_3 = QtGui.QLabel(jenvdlg)
        self.label_3.setGeometry(QtCore.QRect(40, 160, 66, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.ename = QtGui.QLineEdit(jenvdlg)
        self.ename.setGeometry(QtCore.QRect(130, 100, 281, 27))
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setPointSize(10)
        self.ename.setFont(font)
        self.ename.setObjectName(_fromUtf8("ename"))
        self.evalue = QtGui.QLineEdit(jenvdlg)
        self.evalue.setGeometry(QtCore.QRect(130, 160, 731, 27))
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.evalue.setFont(font)
        self.evalue.setObjectName(_fromUtf8("evalue"))

        self.retranslateUi(jenvdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jenvdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jenvdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jenvdlg)
        jenvdlg.setTabOrder(self.ename, self.evalue)
        jenvdlg.setTabOrder(self.evalue, self.buttonBox)

    def retranslateUi(self, jenvdlg):
        jenvdlg.setWindowTitle(QtGui.QApplication.translate("jenvdlg", "Edit environment variable", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jenvdlg", "Environment variable for job", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("jenvdlg", "Name", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("jenvdlg", "Value", None, QtGui.QApplication.UnicodeUTF8))
        self.ename.setToolTip(QtGui.QApplication.translate("jenvdlg", "This is the name of the variable", None, QtGui.QApplication.UnicodeUTF8))
        self.evalue.setToolTip(QtGui.QApplication.translate("jenvdlg", "This is the value of the variable", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jobviewdlg.ui'
#
# Created: Sat Oct 27 12:21:55 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jobviewdlg(object):
    def setupUi(self, jobviewdlg):
        jobviewdlg.setObjectName(_fromUtf8("jobviewdlg"))
        jobviewdlg.resize(638, 526)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8("btqwdoc.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        jobviewdlg.setWindowIcon(icon)
        jobviewdlg.setAutoFillBackground(False)
        jobviewdlg.setSizeGripEnabled(True)
        self.verticalLayout_2 = QtGui.QVBoxLayout(jobviewdlg)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.verticalLayout = QtGui.QVBoxLayout()
        self.verticalLayout.setSizeConstraint(QtGui.QLayout.SetDefaultConstraint)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.horizontalLayout = QtGui.QHBoxLayout()
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.label = QtGui.QLabel(jobviewdlg)
        self.label.setObjectName(_fromUtf8("label"))
        self.horizontalLayout.addWidget(self.label)
        self.jobdescr = QtGui.QLineEdit(jobviewdlg)
        self.jobdescr.setReadOnly(True)
        self.jobdescr.setObjectName(_fromUtf8("jobdescr"))
        self.horizontalLayout.addWidget(self.jobdescr)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.jobtext = QtGui.QPlainTextEdit(jobviewdlg)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.jobtext.sizePolicy().hasHeightForWidth())
        self.jobtext.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier 10 Pitch"))
        self.jobtext.setFont(font)
        self.jobtext.setLineWrapMode(QtGui.QPlainTextEdit.NoWrap)
        self.jobtext.setReadOnly(True)
        self.jobtext.setObjectName(_fromUtf8("jobtext"))
        self.verticalLayout.addWidget(self.jobtext)
        self.buttonBox = QtGui.QDialogButtonBox(jobviewdlg)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Close)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.verticalLayout.addWidget(self.buttonBox)
        self.verticalLayout_2.addLayout(self.verticalLayout)

        self.retranslateUi(jobviewdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jobviewdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jobviewdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jobviewdlg)
        jobviewdlg.setTabOrder(self.jobdescr, self.jobtext)
        jobviewdlg.setTabOrder(self.jobtext, self.buttonBox)

    def retranslateUi(self, jobviewdlg):
        jobviewdlg.setWindowTitle(QtGui.QApplication.translate("jobviewdlg", "Job View", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jobviewdlg", "Viewing job", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jargdlg.ui'
#
# Created: Mon Nov 19 13:03:21 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jargdlg(object):
    def setupUi(self, jargdlg):
        jargdlg.setObjectName(_fromUtf8("jargdlg"))
        jargdlg.resize(560, 223)
        self.buttonBox = QtGui.QDialogButtonBox(jargdlg)
        self.buttonBox.setGeometry(QtCore.QRect(210, 160, 341, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edjob = QtGui.QLabel(jargdlg)
        self.edjob.setGeometry(QtCore.QRect(140, 40, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label = QtGui.QLabel(jargdlg)
        self.label.setGeometry(QtCore.QRect(40, 40, 91, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.argument = QtGui.QLineEdit(jargdlg)
        self.argument.setGeometry(QtCore.QRect(40, 80, 491, 27))
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.argument.setFont(font)
        self.argument.setObjectName(_fromUtf8("argument"))

        self.retranslateUi(jargdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jargdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jargdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jargdlg)
        jargdlg.setTabOrder(self.argument, self.buttonBox)

    def retranslateUi(self, jargdlg):
        jargdlg.setWindowTitle(QtGui.QApplication.translate("jargdlg", "Job argument", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jargdlg", "Arg for job:", None, QtGui.QApplication.UnicodeUTF8))
        self.argument.setToolTip(QtGui.QApplication.translate("jargdlg", "This is the argument string, remember that environment variables $name\n"
"will be subsituted, together with %t for the job title and other data.", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'progopts.ui'
#
# Created: Tue Aug 14 11:40:54 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_Progopts(object):
    def setupUi(self, Progopts):
        Progopts.setObjectName(_fromUtf8("Progopts"))
        Progopts.resize(400, 233)
        self.buttonBox = QtGui.QDialogButtonBox(Progopts)
        self.buttonBox.setGeometry(QtCore.QRect(290, 20, 81, 111))
        self.buttonBox.setOrientation(QtCore.Qt.Vertical)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.confdel = QtGui.QGroupBox(Progopts)
        self.confdel.setGeometry(QtCore.QRect(20, 10, 231, 111))
        self.confdel.setObjectName(_fromUtf8("confdel"))
        self.layoutWidget = QtGui.QWidget(self.confdel)
        self.layoutWidget.setGeometry(QtCore.QRect(20, 29, 191, 61))
        self.layoutWidget.setObjectName(_fromUtf8("layoutWidget"))
        self.verticalLayout = QtGui.QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setMargin(0)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.confNever = QtGui.QRadioButton(self.layoutWidget)
        self.confNever.setObjectName(_fromUtf8("confNever"))
        self.verticalLayout.addWidget(self.confNever)
        self.confAlways = QtGui.QRadioButton(self.layoutWidget)
        self.confAlways.setChecked(True)
        self.confAlways.setObjectName(_fromUtf8("confAlways"))
        self.verticalLayout.addWidget(self.confAlways)
        self.layoutWidget_2 = QtGui.QWidget(Progopts)
        self.layoutWidget_2.setGeometry(QtCore.QRect(40, 180, 241, 41))
        self.layoutWidget_2.setObjectName(_fromUtf8("layoutWidget_2"))
        self.horizontalLayout_2 = QtGui.QHBoxLayout(self.layoutWidget_2)
        self.horizontalLayout_2.setMargin(0)
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.label_2 = QtGui.QLabel(self.layoutWidget_2)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.horizontalLayout_2.addWidget(self.label_2)
        self.udpwaittime = QtGui.QSpinBox(self.layoutWidget_2)
        self.udpwaittime.setMinimum(1)
        self.udpwaittime.setMaximum(32767)
        self.udpwaittime.setSingleStep(50)
        self.udpwaittime.setProperty("value", 750)
        self.udpwaittime.setObjectName(_fromUtf8("udpwaittime"))
        self.horizontalLayout_2.addWidget(self.udpwaittime)
        self.unqueuebin = QtGui.QCheckBox(Progopts)
        self.unqueuebin.setGeometry(QtCore.QRect(40, 130, 151, 22))
        self.unqueuebin.setObjectName(_fromUtf8("unqueuebin"))
        self.label_2.setBuddy(self.udpwaittime)

        self.retranslateUi(Progopts)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), Progopts.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), Progopts.reject)
        QtCore.QMetaObject.connectSlotsByName(Progopts)
        Progopts.setTabOrder(self.confNever, self.confAlways)
        Progopts.setTabOrder(self.confAlways, self.unqueuebin)
        Progopts.setTabOrder(self.unqueuebin, self.udpwaittime)
        Progopts.setTabOrder(self.udpwaittime, self.buttonBox)

    def retranslateUi(self, Progopts):
        Progopts.setWindowTitle(QtGui.QApplication.translate("Progopts", "Program Options", None, QtGui.QApplication.UnicodeUTF8))
        self.confdel.setTitle(QtGui.QApplication.translate("Progopts", "Delete Job Confirmation", None, QtGui.QApplication.UnicodeUTF8))
        self.confNever.setToolTip(QtGui.QApplication.translate("Progopts", "Do not ask confirmation before deleting a job - just delete", None, QtGui.QApplication.UnicodeUTF8))
        self.confNever.setText(QtGui.QApplication.translate("Progopts", "&Never - just delete", None, QtGui.QApplication.UnicodeUTF8))
        self.confAlways.setToolTip(QtGui.QApplication.translate("Progopts", "Always ask confirmation before deleting any job", None, QtGui.QApplication.UnicodeUTF8))
        self.confAlways.setText(QtGui.QApplication.translate("Progopts", "&Ask first", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("Progopts", "&UDP wait time", None, QtGui.QApplication.UnicodeUTF8))
        self.udpwaittime.setToolTip(QtGui.QApplication.translate("Progopts", "Set wait time for UDP calls (login/logout)", None, QtGui.QApplication.UnicodeUTF8))
        self.udpwaittime.setSuffix(QtGui.QApplication.translate("Progopts", " ms", None, QtGui.QApplication.UnicodeUTF8))
        self.unqueuebin.setToolTip(QtGui.QApplication.translate("Progopts", "Unqueue job in binary mode.\n"
"(I.e. on Windows clients don\'t convert line endings to CRLF).", None, QtGui.QApplication.UnicodeUTF8))
        self.unqueuebin.setText(QtGui.QApplication.translate("Progopts", "Unqueue as binary", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jredirdlg.ui'
#
# Created: Tue Nov 20 19:58:14 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jredirdlg(object):
    def setupUi(self, jredirdlg):
        jredirdlg.setObjectName(_fromUtf8("jredirdlg"))
        jredirdlg.resize(568, 300)
        self.buttonBox = QtGui.QDialogButtonBox(jredirdlg)
        self.buttonBox.setGeometry(QtCore.QRect(290, 260, 211, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(jredirdlg)
        self.label.setGeometry(QtCore.QRect(30, 20, 141, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.edjob = QtGui.QLabel(jredirdlg)
        self.edjob.setGeometry(QtCore.QRect(170, 20, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label_2 = QtGui.QLabel(jredirdlg)
        self.label_2.setGeometry(QtCore.QRect(30, 60, 101, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.fd = QtGui.QSpinBox(jredirdlg)
        self.fd.setGeometry(QtCore.QRect(140, 60, 81, 27))
        self.fd.setMaximum(1023)
        self.fd.setSingleStep(1)
        self.fd.setProperty("value", 100)
        self.fd.setObjectName(_fromUtf8("fd"))
        self.expl = QtGui.QLabel(jredirdlg)
        self.expl.setGeometry(QtCore.QRect(300, 60, 181, 17))
        self.expl.setText(_fromUtf8(""))
        self.expl.setObjectName(_fromUtf8("expl"))
        self.label_3 = QtGui.QLabel(jredirdlg)
        self.label_3.setGeometry(QtCore.QRect(30, 160, 91, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.filename = QtGui.QLineEdit(jredirdlg)
        self.filename.setGeometry(QtCore.QRect(140, 160, 391, 27))
        self.filename.setObjectName(_fromUtf8("filename"))
        self.action = QtGui.QComboBox(jredirdlg)
        self.action.setGeometry(QtCore.QRect(140, 110, 101, 27))
        self.action.setObjectName(_fromUtf8("action"))
        self.action.addItem(_fromUtf8(""))
        self.action.addItem(_fromUtf8(""))
        self.action.addItem(_fromUtf8(""))
        self.action.addItem(_fromUtf8(""))
        self.action.addItem(_fromUtf8(""))
        self.action.addItem(_fromUtf8(""))
        self.action.addItem(_fromUtf8(""))
        self.action.addItem(_fromUtf8(""))
        self.action.addItem(_fromUtf8(""))
        self.label_4 = QtGui.QLabel(jredirdlg)
        self.label_4.setGeometry(QtCore.QRect(30, 110, 66, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.label_5 = QtGui.QLabel(jredirdlg)
        self.label_5.setGeometry(QtCore.QRect(30, 210, 91, 17))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.fd2 = QtGui.QSpinBox(jredirdlg)
        self.fd2.setGeometry(QtCore.QRect(140, 210, 81, 27))
        self.fd2.setMaximum(1023)
        self.fd2.setObjectName(_fromUtf8("fd2"))

        self.retranslateUi(jredirdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jredirdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jredirdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jredirdlg)
        jredirdlg.setTabOrder(self.fd, self.action)
        jredirdlg.setTabOrder(self.action, self.filename)
        jredirdlg.setTabOrder(self.filename, self.fd2)
        jredirdlg.setTabOrder(self.fd2, self.buttonBox)

    def retranslateUi(self, jredirdlg):
        jredirdlg.setWindowTitle(QtGui.QApplication.translate("jredirdlg", "Job redirection", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jredirdlg", "Redirection for job:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("jredirdlg", "FD Applied to", None, QtGui.QApplication.UnicodeUTF8))
        self.fd.setToolTip(QtGui.QApplication.translate("jredirdlg", "This is the file descriptor which the redirection applies to", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("jredirdlg", "File/program", None, QtGui.QApplication.UnicodeUTF8))
        self.filename.setToolTip(QtGui.QApplication.translate("jredirdlg", "This is the file name to which the file redirections apply.\n"
"\n"
"For \"pipe to\" and \"pipe from\" operations, this gives the program\n"
"name.", None, QtGui.QApplication.UnicodeUTF8))
        self.action.setToolTip(QtGui.QApplication.translate("jredirdlg", "These are the possible actions of the redirection", None, QtGui.QApplication.UnicodeUTF8))
        self.action.setItemText(0, QtGui.QApplication.translate("jredirdlg", "Read", None, QtGui.QApplication.UnicodeUTF8))
        self.action.setItemText(1, QtGui.QApplication.translate("jredirdlg", "Write", None, QtGui.QApplication.UnicodeUTF8))
        self.action.setItemText(2, QtGui.QApplication.translate("jredirdlg", "Append", None, QtGui.QApplication.UnicodeUTF8))
        self.action.setItemText(3, QtGui.QApplication.translate("jredirdlg", "Read / Write", None, QtGui.QApplication.UnicodeUTF8))
        self.action.setItemText(4, QtGui.QApplication.translate("jredirdlg", "Read / Append", None, QtGui.QApplication.UnicodeUTF8))
        self.action.setItemText(5, QtGui.QApplication.translate("jredirdlg", "Pipe to", None, QtGui.QApplication.UnicodeUTF8))
        self.action.setItemText(6, QtGui.QApplication.translate("jredirdlg", "Pipe from", None, QtGui.QApplication.UnicodeUTF8))
        self.action.setItemText(7, QtGui.QApplication.translate("jredirdlg", "Close", None, QtGui.QApplication.UnicodeUTF8))
        self.action.setItemText(8, QtGui.QApplication.translate("jredirdlg", "Dup FD", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("jredirdlg", "Action", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("jredirdlg", "FD dup from", None, QtGui.QApplication.UnicodeUTF8))
        self.fd2.setToolTip(QtGui.QApplication.translate("jredirdlg", "This is the second file descriptior from which the first one\n"
"is duplicated, if applicable.", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'convaldlg.ui'
#
# Created: Sun Nov 25 22:30:14 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_convaldlg(object):
    def setupUi(self, convaldlg):
        convaldlg.setObjectName(_fromUtf8("convaldlg"))
        convaldlg.resize(400, 185)
        self.buttonBox = QtGui.QDialogButtonBox(convaldlg)
        self.buttonBox.setGeometry(QtCore.QRect(170, 130, 211, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(convaldlg)
        self.label.setGeometry(QtCore.QRect(40, 30, 241, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.conval = QtGui.QSpinBox(convaldlg)
        self.conval.setGeometry(QtCore.QRect(120, 70, 81, 27))
        self.conval.setMinimum(-1000)
        self.conval.setMaximum(1000)
        self.conval.setObjectName(_fromUtf8("conval"))

        self.retranslateUi(convaldlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), convaldlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), convaldlg.reject)
        QtCore.QMetaObject.connectSlotsByName(convaldlg)
        convaldlg.setTabOrder(self.conval, self.buttonBox)

    def retranslateUi(self, convaldlg):
        convaldlg.setWindowTitle(QtGui.QApplication.translate("convaldlg", "Constant for arith ops", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("convaldlg", "Constant for arithment operations", None, QtGui.QApplication.UnicodeUTF8))
        self.conval.setToolTip(QtGui.QApplication.translate("convaldlg", "This is the constant which will be used for\n"
"arithmetic operations on variables.", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'btrprogopts.ui'
#
# Created: Tue Jan 29 13:25:38 2013
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_btrwprogopts(object):
    def setupUi(self, btrwprogopts):
        btrwprogopts.setObjectName(_fromUtf8("btrwprogopts"))
        btrwprogopts.resize(507, 394)
        self.buttonBox = QtGui.QDialogButtonBox(btrwprogopts)
        self.buttonBox.setGeometry(QtCore.QRect(290, 350, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(btrwprogopts)
        self.label.setGeometry(QtCore.QRect(30, 40, 101, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.defserver = QtGui.QComboBox(btrwprogopts)
        self.defserver.setGeometry(QtCore.QRect(140, 40, 191, 27))
        self.defserver.setEditable(True)
        self.defserver.setObjectName(_fromUtf8("defserver"))
        self.useexted = QtGui.QCheckBox(btrwprogopts)
        self.useexted.setGeometry(QtCore.QRect(30, 130, 141, 22))
        self.useexted.setObjectName(_fromUtf8("useexted"))
        self.edname = QtGui.QLineEdit(btrwprogopts)
        self.edname.setEnabled(False)
        self.edname.setGeometry(QtCore.QRect(30, 170, 261, 27))
        self.edname.setObjectName(_fromUtf8("edname"))
        self.interm = QtGui.QCheckBox(btrwprogopts)
        self.interm.setEnabled(False)
        self.interm.setGeometry(QtCore.QRect(40, 210, 121, 22))
        self.interm.setObjectName(_fromUtf8("interm"))
        self.shellarg = QtGui.QLineEdit(btrwprogopts)
        self.shellarg.setEnabled(False)
        self.shellarg.setGeometry(QtCore.QRect(120, 310, 231, 27))
        self.shellarg.setObjectName(_fromUtf8("shellarg"))
        self.label_3 = QtGui.QLabel(btrwprogopts)
        self.label_3.setGeometry(QtCore.QRect(30, 320, 66, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.shell = QtGui.QComboBox(btrwprogopts)
        self.shell.setEnabled(False)
        self.shell.setGeometry(QtCore.QRect(120, 260, 231, 27))
        self.shell.setEditable(True)
        self.shell.setObjectName(_fromUtf8("shell"))
        self.shell.addItem(_fromUtf8(""))
        self.shell.addItem(_fromUtf8(""))
        self.shell.addItem(_fromUtf8(""))
        self.label_2 = QtGui.QLabel(btrwprogopts)
        self.label_2.setGeometry(QtCore.QRect(30, 260, 66, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.verbose = QtGui.QCheckBox(btrwprogopts)
        self.verbose.setGeometry(QtCore.QRect(30, 90, 111, 22))
        self.verbose.setObjectName(_fromUtf8("verbose"))

        self.retranslateUi(btrwprogopts)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), btrwprogopts.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), btrwprogopts.reject)
        QtCore.QMetaObject.connectSlotsByName(btrwprogopts)
        btrwprogopts.setTabOrder(self.defserver, self.verbose)
        btrwprogopts.setTabOrder(self.verbose, self.useexted)
        btrwprogopts.setTabOrder(self.useexted, self.edname)
        btrwprogopts.setTabOrder(self.edname, self.interm)
        btrwprogopts.setTabOrder(self.interm, self.shell)
        btrwprogopts.setTabOrder(self.shell, self.shellarg)
        btrwprogopts.setTabOrder(self.shellarg, self.buttonBox)

    def retranslateUi(self, btrwprogopts):
        btrwprogopts.setWindowTitle(QtGui.QApplication.translate("btrwprogopts", "Program Options", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("btrwprogopts", "Main Server", None, QtGui.QApplication.UnicodeUTF8))
        self.defserver.setToolTip(QtGui.QApplication.translate("btrwprogopts", "This is the server normally used to submit jobs unless another is selected", None, QtGui.QApplication.UnicodeUTF8))
        self.useexted.setToolTip(QtGui.QApplication.translate("btrwprogopts", "Select this if you want to use an external editor", None, QtGui.QApplication.UnicodeUTF8))
        self.useexted.setText(QtGui.QApplication.translate("btrwprogopts", "External Editor", None, QtGui.QApplication.UnicodeUTF8))
        self.edname.setToolTip(QtGui.QApplication.translate("btrwprogopts", "Give the name of an external editor to use here", None, QtGui.QApplication.UnicodeUTF8))
        self.interm.setToolTip(QtGui.QApplication.translate("btrwprogopts", "Run external editor via shell", None, QtGui.QApplication.UnicodeUTF8))
        self.interm.setText(QtGui.QApplication.translate("btrwprogopts", "Run in shell", None, QtGui.QApplication.UnicodeUTF8))
        self.shellarg.setToolTip(QtGui.QApplication.translate("btrwprogopts", "<html><head/><body><p>This is the argument to be passed to the terminal program to make it take the rest of the command line as arguments to passed to the editor.</p><p>For <span style=\" font-weight:600;\">xterm</span> and <span style=\" font-weight:600;\">konsole</span> the argument <span style=\" font-weight:600;\">-e</span> is used.</p><p>For <span style=\" font-weight:600;\">gnome-terminal</span> the argumens <span style=\" font-weight:600;\">--disable-factory</span><span style=\" font-weight:600;\">-x</span> is used.</p><p>For other terminal programs you may need to consult the manual<br/></p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.shellarg.setText(QtGui.QApplication.translate("btrwprogopts", "e", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("btrwprogopts", "Argument", None, QtGui.QApplication.UnicodeUTF8))
        self.shell.setToolTip(QtGui.QApplication.translate("btrwprogopts", "<html><head/><body><p>For external editors which have to be run in a shell, this is the name of the terminal program to use.</p><p>Alternatives of <span style=\" font-style:italic;\">xterm</span>, <span style=\" font-style:italic;\">konsole</span> and <span style=\" font-style:italic;\">gnome-terminal</span> are known about, but you can put another one in if you wish.</p><p>You can add additional options like <span style=\" font-weight:600;\">-bg blue</span> or similar here</p><p>In most cases you will have to supply an argument to the command to make it interpret the rest of the command line as arguments to the editor, which is done in the following argument.</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.shell.setItemText(0, QtGui.QApplication.translate("btrwprogopts", "xterm", None, QtGui.QApplication.UnicodeUTF8))
        self.shell.setItemText(1, QtGui.QApplication.translate("btrwprogopts", "gnome-terminal", None, QtGui.QApplication.UnicodeUTF8))
        self.shell.setItemText(2, QtGui.QApplication.translate("btrwprogopts", "konsole", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("btrwprogopts", "Terminal", None, QtGui.QApplication.UnicodeUTF8))
        self.verbose.setToolTip(QtGui.QApplication.translate("btrwprogopts", "Display results of submission even if successful", None, QtGui.QApplication.UnicodeUTF8))
        self.verbose.setText(QtGui.QApplication.translate("btrwprogopts", "Verbose", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'varcommdlg.ui'
#
# Created: Sun Nov 25 22:42:04 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_varcommdlg(object):
    def setupUi(self, varcommdlg):
        varcommdlg.setObjectName(_fromUtf8("varcommdlg"))
        varcommdlg.resize(580, 225)
        self.buttonBox = QtGui.QDialogButtonBox(varcommdlg)
        self.buttonBox.setGeometry(QtCore.QRect(320, 160, 201, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(varcommdlg)
        self.label.setGeometry(QtCore.QRect(40, 40, 141, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.edvar = QtGui.QLabel(varcommdlg)
        self.edvar.setGeometry(QtCore.QRect(180, 40, 301, 17))
        self.edvar.setText(_fromUtf8(""))
        self.edvar.setObjectName(_fromUtf8("edvar"))
        self.comment = QtGui.QLineEdit(varcommdlg)
        self.comment.setGeometry(QtCore.QRect(100, 100, 381, 27))
        self.comment.setMaxLength(41)
        self.comment.setObjectName(_fromUtf8("comment"))

        self.retranslateUi(varcommdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), varcommdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), varcommdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(varcommdlg)
        varcommdlg.setTabOrder(self.comment, self.buttonBox)

    def retranslateUi(self, varcommdlg):
        varcommdlg.setWindowTitle(QtGui.QApplication.translate("varcommdlg", "Description/Comment on variable", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("varcommdlg", "Description of var", None, QtGui.QApplication.UnicodeUTF8))
        self.comment.setToolTip(QtGui.QApplication.translate("varcommdlg", "This is a description or comment about the variable", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'titprilldlg.ui'
#
# Created: Tue Nov 13 19:26:45 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_titprilldlg(object):
    def setupUi(self, titprilldlg):
        titprilldlg.setObjectName(_fromUtf8("titprilldlg"))
        titprilldlg.resize(618, 300)
        self.buttonBox = QtGui.QDialogButtonBox(titprilldlg)
        self.buttonBox.setGeometry(QtCore.QRect(400, 250, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(titprilldlg)
        self.label.setGeometry(QtCore.QRect(30, 20, 81, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.edjob = QtGui.QLabel(titprilldlg)
        self.edjob.setGeometry(QtCore.QRect(130, 20, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label_2 = QtGui.QLabel(titprilldlg)
        self.label_2.setGeometry(QtCore.QRect(30, 70, 66, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.title = QtGui.QLineEdit(titprilldlg)
        self.title.setGeometry(QtCore.QRect(110, 70, 481, 27))
        self.title.setObjectName(_fromUtf8("title"))
        self.label_3 = QtGui.QLabel(titprilldlg)
        self.label_3.setGeometry(QtCore.QRect(30, 120, 66, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.priority = QtGui.QSpinBox(titprilldlg)
        self.priority.setGeometry(QtCore.QRect(110, 120, 61, 27))
        self.priority.setMinimum(1)
        self.priority.setMaximum(255)
        self.priority.setProperty("value", 150)
        self.priority.setObjectName(_fromUtf8("priority"))
        self.rounddll = QtGui.QPushButton(titprilldlg)
        self.rounddll.setGeometry(QtCore.QRect(200, 120, 121, 27))
        self.rounddll.setObjectName(_fromUtf8("rounddll"))
        self.roundull = QtGui.QPushButton(titprilldlg)
        self.roundull.setGeometry(QtCore.QRect(360, 120, 121, 27))
        self.roundull.setObjectName(_fromUtf8("roundull"))
        self.llev = QtGui.QSlider(titprilldlg)
        self.llev.setGeometry(QtCore.QRect(110, 170, 481, 29))
        self.llev.setMinimum(1)
        self.llev.setMaximum(65535)
        self.llev.setPageStep(100)
        self.llev.setProperty("value", 1000)
        self.llev.setOrientation(QtCore.Qt.Horizontal)
        self.llev.setTickPosition(QtGui.QSlider.TicksAbove)
        self.llev.setTickInterval(1000)
        self.llev.setObjectName(_fromUtf8("llev"))
        self.label_4 = QtGui.QLabel(titprilldlg)
        self.label_4.setGeometry(QtCore.QRect(30, 180, 66, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.label_5 = QtGui.QLabel(titprilldlg)
        self.label_5.setGeometry(QtCore.QRect(30, 230, 81, 17))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.cmdint = QtGui.QComboBox(titprilldlg)
        self.cmdint.setGeometry(QtCore.QRect(130, 230, 141, 27))
        self.cmdint.setObjectName(_fromUtf8("cmdint"))
        self.llval = QtGui.QLabel(titprilldlg)
        self.llval.setGeometry(QtCore.QRect(510, 120, 66, 17))
        self.llval.setText(_fromUtf8(""))
        self.llval.setObjectName(_fromUtf8("llval"))

        self.retranslateUi(titprilldlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), titprilldlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), titprilldlg.reject)
        QtCore.QMetaObject.connectSlotsByName(titprilldlg)
        titprilldlg.setTabOrder(self.title, self.priority)
        titprilldlg.setTabOrder(self.priority, self.rounddll)
        titprilldlg.setTabOrder(self.rounddll, self.roundull)
        titprilldlg.setTabOrder(self.roundull, self.llev)
        titprilldlg.setTabOrder(self.llev, self.cmdint)
        titprilldlg.setTabOrder(self.cmdint, self.buttonBox)

    def retranslateUi(self, titprilldlg):
        titprilldlg.setWindowTitle(QtGui.QApplication.translate("titprilldlg", "Title, priority, load level, cmd interpreter", None, QtGui.QApplication.UnicodeUTF8))
        titprilldlg.setToolTip(QtGui.QApplication.translate("titprilldlg", "Press this button to round down the load level", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("titprilldlg", "Editing job:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("titprilldlg", "Title:", None, QtGui.QApplication.UnicodeUTF8))
        self.title.setToolTip(QtGui.QApplication.translate("titprilldlg", "This is the job title displayed for the job", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("titprilldlg", "Priority", None, QtGui.QApplication.UnicodeUTF8))
        self.priority.setToolTip(QtGui.QApplication.translate("titprilldlg", "This is the priority for the job, which in general may be between 1 and 255.\n"
"\n"
"However you may be limited to a particular range on the server where the\n"
"job lives.", None, QtGui.QApplication.UnicodeUTF8))
        self.rounddll.setText(QtGui.QApplication.translate("titprilldlg", "Round LL down", None, QtGui.QApplication.UnicodeUTF8))
        self.roundull.setToolTip(QtGui.QApplication.translate("titprilldlg", "Press this button to round up the load level", None, QtGui.QApplication.UnicodeUTF8))
        self.roundull.setText(QtGui.QApplication.translate("titprilldlg", "Round LL up", None, QtGui.QApplication.UnicodeUTF8))
        self.llev.setToolTip(QtGui.QApplication.translate("titprilldlg", "This is the required load level.\n"
"\n"
"Note that this is reset to the default for the command interpreter\n"
"when that is changed.\n"
"\n"
"You may not be able to change this from the default if you do not\n"
"have \"special create\" permission.", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("titprilldlg", "Load Lev", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("titprilldlg", "Cmd interp", None, QtGui.QApplication.UnicodeUTF8))
        self.cmdint.setToolTip(QtGui.QApplication.translate("titprilldlg", "This is the required command interpreter", None, QtGui.QApplication.UnicodeUTF8))

